

using System;
using System.Data;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using JTC.MiniCommerce.Core;
using JTC.MiniCommerce.Localization;
using JTC.MiniCommerce.Store;
using JTC.MiniCommerce.Store.Services;
using JTC.MiniCommerce.Store.Services.PaymentService;
using JTC.MiniCommerce.Store.Web.Controls;

namespace JTC.MiniCommerce.Web.admin.controls.configuration.paymentproviders {
  public partial class paypalproconfiguration : PaymentConfigurationControl {

    #region Member Variables
    
    ProviderSettings payPalProConfigurationSettings = null;
    PaymentServiceSettings paymentServiceSettings;
    
    #endregion
    
    #region Page Events

    /// <summary>
    /// Handles the Load event of the Page control.
    /// </summary>
    /// <param name="sender">The source of the event.</param>
    /// <param name="e">The <see cref="T:System.EventArgs"/> instance containing the event data.</param>
    protected void Page_Load(object sender, EventArgs e) {
      try {
        SetPayPalProConfigurationProperties();
        paymentServiceSettings = PaymentService.FetchConfiguredPaymentProviders();
        if(paymentServiceSettings != null) {
          foreach(ProviderSettings providerSettings in paymentServiceSettings.ProviderSettingsCollection) {
            if(providerSettings.Name == typeof(PayPalProPaymentProvider).Name) {
              payPalProConfigurationSettings = providerSettings;
            }
          }
          if(payPalProConfigurationSettings != null) {
            txtApiUserName.Text = payPalProConfigurationSettings.Parameters[PayPalProPaymentProvider.API_USERNAME];
            txtApiPassword.Text = payPalProConfigurationSettings.Parameters[PayPalProPaymentProvider.API_PASSWORD];
            txtSignature.Text = payPalProConfigurationSettings.Parameters[PayPalProPaymentProvider.SIGNATURE];
            bool isLive = false;
            bool isParsed = bool.TryParse(payPalProConfigurationSettings.Parameters[PayPalProPaymentProvider.ISLIVE], out isLive);
            chkIsLive.Checked = isLive;
          }
        }
        else {
          paymentServiceSettings = new PaymentServiceSettings();
        }
      }
      catch(Exception ex) {
        Logger.Error(typeof(paypalproconfiguration).Name + ".Page_Load", ex);
        base.MasterPage.MessageCenter.DisplayCriticalMessage(LocalizationUtility.GetCriticalMessageText(ex.Message));
      }     
    }

    /// <summary>
    /// Handles the Click event of the btnSave control.
    /// </summary>
    /// <param name="sender">The source of the event.</param>
    /// <param name="e">The <see cref="T:System.EventArgs"/> instance containing the event data.</param>
    protected void btnSave_Click(object sender, EventArgs e) {
      try {
        if (payPalProConfigurationSettings == null) {
          payPalProConfigurationSettings = new ProviderSettings(typeof(PayPalProPaymentProvider).Name, typeof(PayPalProPaymentProvider).AssemblyQualifiedName);
          paymentServiceSettings.ProviderSettingsCollection.Add(payPalProConfigurationSettings);
        }
        payPalProConfigurationSettings.Parameters.Clear();
        //IMPORTANT: These need to be added in the order they are expected by the constructor used by
        //Activator.CreateInstance in PaymentService
        payPalProConfigurationSettings.Parameters.Add(PayPalProPaymentProvider.API_USERNAME, txtApiUserName.Text.Trim());
        payPalProConfigurationSettings.Parameters.Add(PayPalProPaymentProvider.API_PASSWORD, txtApiPassword.Text.Trim());
        payPalProConfigurationSettings.Parameters.Add(PayPalProPaymentProvider.SIGNATURE, txtSignature.Text.Trim());
        payPalProConfigurationSettings.Parameters.Add(PayPalProPaymentProvider.ISLIVE, chkIsLive.Checked.ToString());
        int id = base.Save(paymentServiceSettings, WebUtility.GetUserName());
        if (id > 0) {
          MasterPage.MessageCenter.DisplaySuccessMessage(LocalizationUtility.GetText("lblPaymentConfigurationSaved"));
        }
        else {
          MasterPage.MessageCenter.DisplayFailureMessage(LocalizationUtility.GetText("lblPaymentConfigurationNotSaved"));
        }
      }
      catch(Exception ex) {
        Logger.Error(typeof(paypalproconfiguration).Name + ".btnSave_Click", ex);
        base.MasterPage.MessageCenter.DisplayCriticalMessage(LocalizationUtility.GetCriticalMessageText(ex.Message));
      }     
    }
    
    #endregion
    
    #region Methods
    
    #region Private

    /// <summary>
    /// Sets the pay pal pro configuration properties.
    /// </summary>
    private void SetPayPalProConfigurationProperties() {
      ltDescription.Text = HttpUtility.HtmlDecode(base.Provider.Description);
      pnlSettings.GroupingText = LocalizationUtility.GetText("pnlPayPalProConfiguration");
      LocalizationUtility.AddLabelText(lblApiUserName);
      LocalizationUtility.AddHoverHelp(hlApiUserNameHelp);
      LocalizationUtility.AddLabelText(lblApiPassword);
      LocalizationUtility.AddHoverHelp(hlApiPasswordHelp);
      LocalizationUtility.AddLabelText(lblSignature);
      LocalizationUtility.AddHoverHelp(hlApiSignatureHelp);
      LocalizationUtility.AddLabelText(lblIsLive);
      LocalizationUtility.AddHoverHelp(hlIsLiveHelp);
      LocalizationUtility.AddButtonText(btnSave);
      LocalizationUtility.AddRfvErrorMessageText(rfvApiUserName);
      LocalizationUtility.AddRfvErrorMessageText(rfvApiPassword);
      LocalizationUtility.AddRfvErrorMessageText(rfvApiSignature);
      lblDescriptionTitle.Text = LocalizationUtility.GetText("lblPayPalProDescriptionTitle");
    }
    
    #endregion
    
    #endregion
    
  }
}