

using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using JTC.MiniCommerce.Core;
using JTC.MiniCommerce.Store;
using JTC.MiniCommerce.Store.Web.Controls;
using JTC.MiniCommerce.Store.Services.MessageService;
using SubSonic.Utilities;
using JTC.MiniCommerce.Localization;

namespace JTC.MiniCommerce.Web.admin.controls.order {
  public partial class shipping : AdminControl {
    
    #region Member Variables
    
    private int orderId = 0;
    private string view = string.Empty;

    #endregion
    
    #region Page Events

    /// <summary>
    /// Handles the Load event of the Page control.
    /// </summary>
    /// <param name="sender">The source of the event.</param>
    /// <param name="e">The <see cref="T:System.EventArgs"/> instance containing the event data.</param>
    protected void Page_Load(object sender, EventArgs e) {
      try {
        orderId = Utility.GetIntParameter("orderId");
        view = Utility.GetParameter("view");
        if(orderId > 0 && view == "s") {
          SetShippingProperties();
          if(!Page.IsPostBack) {
            LoadShippingTrackingNumber();
          }       
        }
      }
      catch(Exception ex) {
        Logger.Error(typeof(shipping).Name + ".Page_Load", ex);
        base.MasterPage.MessageCenter.DisplayCriticalMessage(LocalizationUtility.GetCriticalMessageText(ex.Message));
      }
    }

    /// <summary>
    /// Handles the Click event of the btnSave control.
    /// </summary>
    /// <param name="sender">The source of the event.</param>
    /// <param name="e">The <see cref="T:System.EventArgs"/> instance containing the event data.</param>
    protected void btnSave_Click(object sender, EventArgs e) {
      if(!string.IsNullOrEmpty(txtShippingTrackingNumber.Text)) {
        try {
          Order order = new Order(orderId);
          order.ShippingTrackingNumber = txtShippingTrackingNumber.Text;
          order.Save(WebUtility.GetUserName());
          MessageService messageService = new MessageService();
          messageService.SendShippingNotificationToCustomer(order);
          base.MasterPage.MessageCenter.DisplaySuccessMessage(LocalizationUtility.GetText("lblShippingSaved"));
        }
        catch(Exception ex) {
          Logger.Error(typeof(shipping).Name + ".btnSave_Click", ex);
          base.MasterPage.MessageCenter.DisplayCriticalMessage(LocalizationUtility.GetCriticalMessageText(ex.Message));
        }
      }
    }

    #endregion

    #region Methods
    
    #region Private

    /// <summary>
    /// Loads the shipping tracking number.
    /// </summary>
    private void LoadShippingTrackingNumber() {
      Order order = new Order(orderId);
      txtShippingTrackingNumber.Text = order.ShippingTrackingNumber;
    }

    /// <summary>
    /// Sets the shipping properties.
    /// </summary>
    private void SetShippingProperties() {
      LocalizationUtility.AddPanelText(pnlShipping);
      LocalizationUtility.AddLabelText(lblShippingTrackingNumber);
      LocalizationUtility.AddButtonText(btnSave);
    }    
    
    #endregion
    
    #endregion
    
  }
}