

using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using JTC.MiniCommerce.Core;
using JTC.MiniCommerce.Localization;
using SubSonic.Utilities;

namespace JTC.MiniCommerce.Web.admin.controls.sitesettings {
  public partial class widgets : SiteSettingsControl {
  
    #region Member Variables
    
    private string view = string.Empty;
    
    #endregion
  
    #region Page Events

    /// <summary>
    /// Handles the Load event of the Page control.
    /// </summary>
    /// <param name="sender">The source of the event.</param>
    /// <param name="e">The <see cref="T:System.EventArgs"/> instance containing the event data.</param>
    protected void Page_Load(object sender, EventArgs e) {
      try {
        view = Utility.GetParameter("view");
        if (view == "w") {
          SetWidgetsProperties();
          if (!Page.IsPostBack) {
            chkDisplayNarrowByManufacturer.Checked = SiteSettings.DisplayNarrowByManufacturer;
            chkDisplayNarrowByPrice.Checked = SiteSettings.DisplayNarrowByPrice;
          }
        }
      }
      catch (Exception ex) {
        Logger.Error(typeof(widgets).Name + ".Page_Load", ex);
        base.MasterPage.MessageCenter.DisplayCriticalMessage(LocalizationUtility.GetCriticalMessageText(ex.Message));
      }
    }

    /// <summary>
    /// Handles the Click event of the btnSave control.
    /// </summary>
    /// <param name="sender">The source of the event.</param>
    /// <param name="e">The <see cref="T:System.EventArgs"/> instance containing the event data.</param>
    protected void btnSave_Click(object sender, EventArgs e) {
      try {
        SiteSettings.DisplayNarrowByManufacturer = chkDisplayNarrowByManufacturer.Checked;
        SiteSettings.DisplayNarrowByPrice = chkDisplayNarrowByPrice.Checked;
        base.Save(SiteSettings);
      }
      catch (Exception ex) {
        Logger.Error(typeof(widgets).Name + ".btnSave_Click", ex);
        base.MasterPage.MessageCenter.DisplayCriticalMessage(LocalizationUtility.GetCriticalMessageText(ex.Message));
      }
    }
    
    #endregion
    
    #region Methods
    
    #region Private

    /// <summary>
    /// Sets the widgets properties.
    /// </summary>
    private void SetWidgetsProperties() {
      this.Page.Title = LocalizationUtility.GetText("titleSiteSettingsWidgets");
      pnlSettings.GroupingText = LocalizationUtility.GetText("pnlWidgets");
      LocalizationUtility.AddLabelText(lblDisplayNarrowByManufacturer);
      LocalizationUtility.AddHoverHelp(hlDisplayNarrowByManufacturerHelp);
      LocalizationUtility.AddLabelText(lblDisplayNarrowByPrice);
      LocalizationUtility.AddHoverHelp(hlDisplayNarrowByPriceHelp);
      LocalizationUtility.AddButtonText(btnSave);
    }
    
    #endregion
    
    #endregion
    
  }
}