

using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using System.IO;
using JTC.MiniCommerce.Core;
using JTC.MiniCommerce.Localization;
using JTC.MiniCommerce.Store;

namespace JTC.MiniCommerce.Web.controls {
  public partial class catalogList : System.Web.UI.UserControl {
  
    #region Member Variables

    private PagedDataSource _pagedDataSource;
    private ProductCollection _productCollection;
    
    #endregion

    #region Page Events

    /// <summary>
    /// Handles the Load event of the Page control.
    /// </summary>
    /// <param name="sender">The source of the event.</param>
    /// <param name="e">The <see cref="T:System.EventArgs"/> instance containing the event data.</param>
    protected void Page_Load(object sender, EventArgs e) {
      try {
        if (this.PagedDataSource != null) {
          dlCatalog.DataSource = this.PagedDataSource;
        }
        else {
          if (this.ProductCollection != null) {
            dlCatalog.DataSource = this.ProductCollection;
          }
        }
        dlCatalog.ItemDataBound += new DataListItemEventHandler(dlCatalog_ItemDataBound);
        dlCatalog.DataBind();
      }
      catch (Exception ex) {
        Logger.Error(typeof(catalogList).Name + ".Page_Load", ex);
      }
    }

    #endregion
    
    #region Methods
    
    #region Protected

    /// <summary>
    /// Gets the navigate URL.
    /// </summary>
    /// <param name="productId">The product id.</param>
    /// <returns></returns>
    protected string GetNavigateUrl(string productId) {
      return string.Format("~/product.aspx?pid={0}", productId);
    }
    
    #endregion
    
    #region Private

    /// <summary>
    /// Handles the ItemDataBound event of the dlCatalog control.
    /// </summary>
    /// <param name="sender">The source of the event.</param>
    /// <param name="e">The <see cref="T:System.Web.UI.WebControls.DataListItemEventArgs"/> instance containing the event data.</param>
    void dlCatalog_ItemDataBound (object sender, DataListItemEventArgs e) {
      if (e.Item.ItemType == ListItemType.Item || e.Item.ItemType == ListItemType.AlternatingItem) {
        Product product = e.Item.DataItem as Product;
        HyperLink imageLink = e.Item.FindControl("hlImageLink") as HyperLink;
        if (imageLink != null) {
          if (!string.IsNullOrEmpty(product.DefaultImagePath)) {
            if (File.Exists(Server.MapPath(product.DefaultImagePath))) {
              imageLink.ImageUrl = product.DefaultImagePath;
            }
          }
        }

        Label retailPrice = e.Item.FindControl("lblRetailPrice") as Label;
        site masterPage = this.Page.Master as site;
        if (masterPage != null) {
          if (masterPage.SiteSettings.DisplayRetailPrice) {
            if (retailPrice != null) {
              retailPrice.Text = StoreUtility.GetFormattedAmount(product.RetailPrice, true);
            }
          }
          else {
            retailPrice.Visible = false;
          }
        }
        Label ourPrice = e.Item.FindControl("lblOurPrice") as Label;
        if (ourPrice != null) {
          ourPrice.Text = StoreUtility.GetFormattedAmount(product.OurPrice, true);
        }
        AjaxControlToolkit.Rating ajaxRating = e.Item.FindControl("ajaxRating") as AjaxControlToolkit.Rating;
        if (ajaxRating != null) {
          ajaxRating.GroupingText = LocalizationUtility.GetText("lblAverageRating");
          ajaxRating.CurrentRating = product.Rating;
        }
      }
    }
    
    #endregion
    
    #endregion
    
    #region Properties

    /// <summary>
    /// Gets or sets the paged data source.
    /// </summary>
    /// <value>The paged data source.</value>
    public PagedDataSource PagedDataSource {
      get {
        return _pagedDataSource;
      }
      set {
        _pagedDataSource = value;
      }
    }

    /// <summary>
    /// Gets or sets the product collection.
    /// </summary>
    /// <value>The product collection.</value>
    public ProductCollection ProductCollection {
      get {
        return _productCollection;
      }
      set {
        _productCollection = value;
      }
    }    
    
    #endregion

  }
}